@@ -5,7 +5,7 @@ from django.db.models import Sum
 from django.contrib import messages
 from django.contrib.auth.decorators import login_required, permission_required
 from django.shortcuts import render, redirect
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from .app_settings import PAYMENT_CORP
 from allianceauth.eveonline.models import EveCorporationInfo
 from esi.decorators import token_required
